"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractAmqpBasePublisher = void 0;
const core_1 = require("@message-queue-toolkit/core");
const AbstractAmqpService_1 = require("./AbstractAmqpService");
class AbstractAmqpBasePublisher extends AbstractAmqpService_1.AbstractAmqpService {
    sendToQueue(message) {
        try {
            this.channel.sendToQueue(this.queueName, (0, core_1.objectToBuffer)(message));
        }
        catch (err) {
            // Unfortunately, reliable retry mechanism can't be implemented with try-catch block,
            // as not all failures end up here. If connection is closed programmatically, it works fine,
            // but if server closes connection unexpectedly (e. g. RabbitMQ is shut down), then we don't land here
            // @ts-ignore
            if (err.message === 'Channel closed') {
                this.logger.error(`AMQP channel closed`);
                void this.reconnect();
            }
            else {
                throw err;
            }
        }
    }
    /* c8 ignore start */
    resolveMessage() {
        throw new Error('Not implemented for publisher');
    }
    /* c8 ignore start */
    processPrehandlers() {
        throw new Error('Not implemented for publisher');
    }
    preHandlerBarrier() {
        throw new Error('Not implemented for publisher');
    }
    resolveNextFunction() {
        throw new Error('Not implemented for publisher');
    }
    processMessage() {
        throw new Error('Not implemented for publisher');
    }
}
exports.AbstractAmqpBasePublisher = AbstractAmqpBasePublisher;
//# sourceMappingURL=AbstractAmqpBasePublisher.js.map