"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractAmqpConsumerMultiSchema = void 0;
const core_1 = require("@message-queue-toolkit/core");
const AbstractAmqpBaseConsumer_1 = require("./AbstractAmqpBaseConsumer");
class AbstractAmqpConsumerMultiSchema extends AbstractAmqpBaseConsumer_1.AbstractAmqpBaseConsumer {
    messageSchemaContainer;
    handlerContainer;
    executionContext;
    constructor(dependencies, options, executionContext) {
        super(dependencies, options);
        const messageSchemas = options.handlers.map((entry) => entry.schema);
        this.messageSchemaContainer = new core_1.MessageSchemaContainer({
            messageSchemas,
            messageTypeField: options.messageTypeField,
        });
        this.handlerContainer = new core_1.HandlerContainer({
            messageTypeField: this.messageTypeField,
            messageHandlers: options.handlers,
        });
        this.executionContext = executionContext;
    }
    resolveSchema(message) {
        return this.messageSchemaContainer.resolveSchema(message);
    }
    async processMessage(message, messageType, 
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    prehandlingOutputs) {
        const handler = this.handlerContainer.resolveHandler(messageType);
        return handler.handler(message, this.executionContext, prehandlingOutputs);
    }
    resolveMessageLog(message, messageType) {
        const handler = this.handlerContainer.resolveHandler(messageType);
        return handler.messageLogFormatter(message);
    }
    processPrehandlers(message, messageType) {
        const handlerConfig = this.handlerContainer.resolveHandler(messageType);
        return this.processPrehandlersInternal(handlerConfig.prehandlers, message);
    }
    // eslint-disable-next-line max-params
    resolveNextFunction(prehandlers, message, index, prehandlerOutput, resolve, reject) {
        return this.resolveNextPreHandlerFunctionInternal(prehandlers, this.executionContext, message, index, prehandlerOutput, resolve, reject);
    }
    async preHandlerBarrier(message, messageType, prehandlerOutput) {
        const handler = this.handlerContainer.resolveHandler(messageType);
        // @ts-ignore
        return handler.preHandlerBarrier
            ? await handler.preHandlerBarrier(message, this.executionContext, prehandlerOutput)
            : {
                isPassing: true,
                output: undefined,
            };
    }
}
exports.AbstractAmqpConsumerMultiSchema = AbstractAmqpConsumerMultiSchema;
//# sourceMappingURL=AbstractAmqpConsumerMultiSchema.js.map