import type { QueueConsumerDependencies, QueueDependencies, NewQueueOptions, ExistingQueueOptions } from '@message-queue-toolkit/core';
import { AbstractQueueService } from '@message-queue-toolkit/core';
import type { Channel, Connection, Message } from 'amqplib';
import type { Options } from 'amqplib/properties';
import type { AMQPLocatorType } from './AbstractAmqpBaseConsumer';
import type { AmqpConnectionManager, ConnectionReceiver } from './AmqpConnectionManager';
export type AMQPDependencies = QueueDependencies & {
    amqpConnectionManager: AmqpConnectionManager;
};
export type AMQPConsumerDependencies = AMQPDependencies & QueueConsumerDependencies;
export type AMQPQueueConfig = Options.AssertQueue;
export type CreateAMQPQueueOptions = {
    queueOptions: AMQPQueueConfig;
    queueName: string;
    updateAttributesIfExists?: boolean;
};
export type AMQPQueueLocatorType = {
    queueName: string;
};
export declare abstract class AbstractAmqpService<MessagePayloadType extends object, DependenciesType extends AMQPDependencies = AMQPDependencies, ExecutionContext = unknown, PrehandlerOutput = unknown, BarrierOutput = unknown> extends AbstractQueueService<MessagePayloadType, Message, DependenciesType, CreateAMQPQueueOptions, AMQPQueueLocatorType, NewQueueOptions<CreateAMQPQueueOptions> | ExistingQueueOptions<AMQPLocatorType>, ExecutionContext, PrehandlerOutput, BarrierOutput> implements ConnectionReceiver {
    protected connection?: Connection;
    private connectionManager;
    protected channel: Channel;
    private isShuttingDown;
    protected readonly queueName: string;
    constructor(dependencies: DependenciesType, options: NewQueueOptions<CreateAMQPQueueOptions> | ExistingQueueOptions<AMQPLocatorType>);
    receiveNewConnection(connection: Connection): Promise<void>;
    private checkQueueExists;
    private destroyChannel;
    init(): Promise<void>;
    reconnect(): Promise<void>;
    close(): Promise<void>;
}
